=============
skystatistics
=============

The ``skystatistics`` module contains various statistical
functions used by ``skymatch.``

.. moduleauthor:: Mihai Cara <help@stsci.edu>

.. currentmodule:: jwst.skymatch.skystatistics

.. automodule:: jwst.skymatch.skystatistics
   :members:
   :undoc-members:
